.. _reference:

###############
NumPy Reference
###############

:Release: |version|
:Date: |today|

.. module:: numpy

This reference manual details functions, modules, and objects
included in Numpy, describing what they are and what they do.
For learning how to use NumPy, see also :ref:`user`.


.. toctree::
   :maxdepth: 2

   arrays
   ufuncs
   routines
   ctypes
   distutils
   c-api
   internals


Acknowledgements
================

Large parts of this manual originate from Travis E. Oliphant's book
`Guide to Numpy <http://www.tramy.us/>`__ (which generously entered
Public Domain in August 2008). The reference documentation for many of
the functions are written by numerous contributors and developers of
Numpy, both prior to and during the
`Numpy Documentation Marathon
<http://scipy.org/Developer_Zone/DocMarathon2008>`__.

Please help to improve NumPy's documentation! Instructions on how to
join the ongoing documentation marathon can be found
`on the scipy.org website <http://scipy.org/Developer_Zone/DocMarathon2008>`__
